@@ -44,6 +44,7 @@ from vdsm.storage import fileUtils
 from vdsm.storage import fileVolume
 from vdsm.storage import mount
 from vdsm.storage import outOfProcess as oop
+from vdsm.storage import sanlock_direct
 from vdsm.storage import sd
 from vdsm.storage import xlease
 from vdsm.storage.persistent import PersistentDict, DictValidator
@@ -838,12 +839,22 @@ class FileStorageDomain(sd.StorageDomain):
 
     # Dump metadata
 
-    def dump(self):
-        return {
+    def dump(self, full=False):
+        result = {
             "metadata": self.getInfo(),
             "volumes": self._dump_volumes()
         }
 
+        if full:
+            if self.hasVolumeLeases():
+                result["leases"] = self._dump_leases()
+                result["lockspace"] = self.dump_lockspace()
+
+            if self.supports_external_leases(self.getVersion()):
+                result["xleases"] = self.dump_external_leases()
+
+        return result
+
     def _dump_volumes(self):
         result = {}
         # Glob *.meta files directly without an iterator which
@@ -896,6 +907,14 @@ class FileStorageDomain(sd.StorageDomain):
 
         return vol_uuid, md
 
+    def _dump_leases(self):
+        return list(sanlock_direct.dump_leases(
+            self.getLeasesFilePath(),
+            # Dump all reserved leases.
+            size=sd.RESERVED_LEASES * self.alignment,
+            block_size=self.block_size,
+            alignment=self.alignment))
+
     # Validating file system features
 
     @classmethod
